@@ -81,12 +81,26 @@ value_eq5d3L_IPD <- function(ind_part_data, eq5d_nrcode) {
       stop("eq5d responses do not seem right")
     } else {
       if (is.na(eq5d_nrcode)) {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- stats::na.omit(eq5d_responses)
+        original_ind <- c()
+        ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <-  which(is.na(eq5d_responses[[i]]))
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       } else {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- eq5d_responses[!ind, ]
+        ind <- c()
+        original_ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <- which(eq5d_responses[[i]] == eq5d_nrcode)
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       }
+      ind <- sort(unique(ind))
+      original_ind <-  sort(unique(original_ind))
+      if (length(ind > 0))
+        eq5d_responses <- eq5d_responses[-ind, ]
       index3L <- rep(0, nrow(eq5d_responses))
       for (i in seq(nrow(eq5d_responses))) {
         index3L[i] <- valueEQ5D::value_3L_Ind(
@@ -96,9 +110,11 @@ value_eq5d3L_IPD <- function(ind_part_data, eq5d_nrcode) {
         )
       }
       new_colname <- paste("EQ5D3LIndex")
-      rows_needed <- rows_needed[!ind]
+      if (length(ind > 0))
+        rows_needed <- rows_needed[-ind]
       ind_part_data[rows_needed, new_colname] <- index3L
-      ind_part_data[ind, new_colname] <- eq5d_nrcode
+      if (length(original_ind > 0))
+        ind_part_data[original_ind, new_colname] <- eq5d_nrcode
     }
   }
   return(ind_part_data)
@@ -150,12 +166,26 @@ value_eq5d5L_IPD <- function(ind_part_data, eq5d_nrcode) {
       stop("eq5d responses do not seem right")
     } else {
       if (is.na(eq5d_nrcode)) {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- stats::na.omit(eq5d_responses)
+        original_ind <- c()
+        ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <-  which(is.na(eq5d_responses[[i]]))
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       } else {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- eq5d_responses[!ind, ]
+        ind <- c()
+        original_ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <- which(eq5d_responses[[i]] == eq5d_nrcode)
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       }
+      ind <- sort(unique(ind))
+      original_ind <-  sort(unique(original_ind))
+      if (length(ind > 0))
+          eq5d_responses <- eq5d_responses[-ind, ]
       index5L <- rep(0, nrow(eq5d_responses))
       for (i in seq(nrow(eq5d_responses))) {
         index5L[i] <- valueEQ5D::value_5L_Ind(
@@ -165,9 +195,11 @@ value_eq5d5L_IPD <- function(ind_part_data, eq5d_nrcode) {
         )
       }
       new_colname <- paste("EQ5D5LIndex")
-      rows_needed <- rows_needed[!ind]
+      if (length(ind > 0))
+          rows_needed <- rows_needed[-ind]
       ind_part_data[rows_needed, new_colname] <- index5L
-      ind_part_data[ind, new_colname] <- eq5d_nrcode
+      if (length(original_ind > 0))
+        ind_part_data[original_ind, new_colname] <- eq5d_nrcode
     }
   }
   return(ind_part_data)
@@ -223,12 +255,26 @@ map_eq5d5Lto3L_VanHout <- function(ind_part_data, eq5d_nrcode) {
       # remove those with non response codes, if missing data has been removed
       # this will do no harm
       if (is.na(eq5d_nrcode)) {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- stats::na.omit(eq5d_responses)
+        original_ind <- c()
+        ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <-  which(is.na(eq5d_responses[[i]]))
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       } else {
-        ind <- Reduce(`|`, lapply(eq5d_responses, function(x) x %in% eq5d_nrcode))
-        eq5d_responses <- eq5d_responses[!ind, ]
+        ind <- c()
+        original_ind <- c()
+        for (i in 1:ncol(eq5d_responses)) {
+          which_one <- which(eq5d_responses[[i]] == eq5d_nrcode)
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       }
+      ind <- sort(unique(ind))
+      original_ind <-  sort(unique(original_ind))
+      if (length(ind > 0))
+          eq5d_responses <- eq5d_responses[-ind, ]
       index5L <- rep(0, nrow(eq5d_responses))
       for (i in seq(nrow(eq5d_responses))) {
         score_5L <- as.numeric(paste(eq5d_responses[i, 1],
@@ -239,9 +285,11 @@ map_eq5d5Lto3L_VanHout <- function(ind_part_data, eq5d_nrcode) {
         index5L[i] <- valueEQ5D::map_5Lto3L_Ind("UK", "CW", score_5L)
       }
       new_colname <- paste("EQ5D3L_from5L")
-      rows_needed <- rows_needed[!ind]
+      if (length(ind > 0))
+          rows_needed <- rows_needed[-ind]
       ind_part_data[rows_needed, new_colname] <- index5L
-      ind_part_data[ind, new_colname] <- eq5d_nrcode
+      if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- eq5d_nrcode
     }
   }
   return(ind_part_data)
@@ -270,7 +318,7 @@ value_ADL_scores_IPD <- function(ind_part_data, adl_related_words,
   if (!is.null(adl_scoring_table))
     adl_scores <- adl_scoring_table
   else
-    adl_scores <- packDAMipd::adl_scoring
+    adl_scores <- packDAMipd::adl_scoring.df
 
   adl_scoring_data_columns <- colnames(adl_scores)
   adl_details <- get_outcome_details(ind_part_data, "adl",
@@ -295,6 +343,29 @@ value_ADL_scores_IPD <- function(ind_part_data, adl_related_words,
     }
     # get ADL responses
     adl_responses <- ind_part_data[rows_needed, adl_columnnames]
+    # remove those with non response codes, if missing data has been removed
+    # this will do no harm
+    if (is.na(adl_nrcode)) {
+      original_ind <- c()
+      ind <- c()
+      for (i in 1:ncol(adl_responses)) {
+        which_one <-  which(is.na(adl_responses[[i]]))
+        original_ind <- append(original_ind, rows_needed[which_one])
+        ind <- append(ind, which_one)
+      }
+    } else {
+      ind <- c()
+      original_ind <- c()
+      for (i in 1:ncol(adl_responses)) {
+        which_one <- which(adl_responses[[i]] == adl_nrcode)
+        original_ind <- append(original_ind, rows_needed[which_one])
+        ind <- append(ind, which_one)
+      }
+    }
+    ind <- sort(unique(ind))
+    original_ind <-  sort(unique(original_ind))
+    if (length(ind > 0))
+      adl_responses <- adl_responses[-ind, ]
     # Check if the responses are 8 for an individual
     if (length(adl_columnnames) != 8) {
       stop("error- ADL should have 8 columns")
@@ -306,15 +377,7 @@ value_ADL_scores_IPD <- function(ind_part_data, adl_related_words,
     if (any(results < 0)) {
       stop("ADL responses do not seem right")
     } else {
-      # remove those with non response codes, if missing data has been removed
-      # this will do no harm
-      if (is.na(adl_nrcode)) {
-        ind <- Reduce(`|`, lapply(adl_responses, function(x) x %in% adl_nrcode))
-        adl_responses <- stats::na.omit(adl_responses)
-      } else {
-        ind <- Reduce(`|`, lapply(adl_responses, function(x) x %in% adl_nrcode))
-        adl_responses <- adl_responses[!ind, ]
-      }
+
       # Check if ADL scoring table has columns defined in the config file
       if (IPDFileCheck::test_columnnames(adl_scoring_data_columns,
                                          adl_scores) == 0) {
@@ -330,9 +393,17 @@ value_ADL_scores_IPD <- function(ind_part_data, adl_related_words,
         }
         # Add the T score to data , save and return
         new_colname <- paste("ADLTscore")
-        rows_needed <- rows_needed[!ind]
+        if (length(ind > 0))
+          rows_needed <- rows_needed[-ind]
         ind_part_data[rows_needed, new_colname] <- TscoreADL
-        ind_part_data[ind, new_colname] <- adl_nrcode
+        if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- adl_nrcode
+
+        # Add the total raw score to data , save and return
+        new_colname <- paste("ADLtotalrawscore")
+        ind_part_data[rows_needed, new_colname] <- sumADL
+        if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- adl_nrcode
       } else {
         stop("Error ADL scoring column names are not equal to what specified
              in configuration file")
@@ -343,8 +414,8 @@ value_ADL_scores_IPD <- function(ind_part_data, adl_related_words,
 }
 ##############################################################################
 #' Function to estimate the cost of tablets taken (from IPD)
-#' @param ind_part_data a dataframe containing IPD
-#' @param shows_related_words a dataframe containing IPD
+#' @param ind_part_data a data frame containing IPD
+#' @param shows_related_words a data frame containing IPD
 #' @param shows_nrcode non response code for ADL, default is NA
 #' @return sum of scores, if success -1, if failure
 #' @examples
@@ -394,19 +465,154 @@ value_Shows_IPD <- function(ind_part_data, shows_related_words, shows_nrcode) {
       # remove those with non response codes, if missing data has been removed
       # this will do no harm
       if (is.na(shows_nrcode)) {
-        ind <- Reduce(`|`, lapply(shows_responses, function(x) x %in% shows_nrcode))
-        shows_responses <- stats::na.omit(shows_responses)
+        original_ind <- c()
+        ind <- c()
+        for (i in 1:ncol(shows_responses)) {
+          which_one <-  which(is.na(shows_responses[[i]]))
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       } else {
-        ind <- Reduce(`|`, lapply(shows_responses, function(x) x %in% shows_nrcode))
-        shows_responses <- shows_responses[!ind, ]
+        ind <- c()
+        original_ind <- c()
+        for (i in 1:ncol(shows_responses)) {
+          which_one <- which(shows_responses[[i]] == shows_nrcode)
+          original_ind <- append(original_ind, rows_needed[which_one])
+          ind <- append(ind, which_one)
+        }
       }
+      ind <- sort(unique(ind))
+      original_ind <-  sort(unique(original_ind))
+      if (length(ind > 0))
+          shows_responses <- shows_responses[-ind, ]
       # Check if shows scoring table has columns defined in the config file
       sumShows <- rowSums(shows_responses) - 10
       # Add the score to data , save and return
       new_colname <- paste("ShOWSscore")
-      rows_needed <- rows_needed[!ind]
+      if (length(ind > 0))
+        rows_needed <- rows_needed[-ind]
       ind_part_data[rows_needed, new_colname] <- sumShows
-      ind_part_data[ind, new_colname] <- shows_nrcode
+      if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- shows_nrcode
+    }
+  }
+  return(ind_part_data)
+}
+
+##############################################################################
+#' Function to convert promis3a scores to a T score
+#' @param ind_part_data a data frame containing IPD data
+#' @param promis3a_related_words related words to find out which columns
+#' contain promis3a data
+#' @param promis3a_nrcode non response code for promis3a
+#' @param promis3a_scoring_table promis3a scoring table, if given as NULL use
+#' the default one
+#' @return promis3a scores converted to T score included modified data, if
+#' success -1, if failure
+#' @examples
+#' trial_data <- data.frame("tpi.q1" = c(1, 2),
+#' "tpi.q2" = c(1, 2), "tpi.q3" = c(1, 2))
+#' results <- value_promis3a_scores_IPD(trial_data, c("tpi"), NA, NULL)
+#' @export
+value_promis3a_scores_IPD <- function(ind_part_data, promis3a_related_words,
+                                 promis3a_nrcode, promis3a_scoring_table = NULL) {
+  #Error - data should not be NULL
+  if (is.null(ind_part_data))
+    stop("data should not be NULL")
+  #Error - data should not be NULL
+  if (!is.null(promis3a_scoring_table))
+    promis3a_scores <- promis3a_scoring_table
+  else
+    promis3a_scores <- promis3a_scoring.df
+
+  promis3a_scoring_data_columns <- colnames(promis3a_scores)
+  promis3a_details <- get_outcome_details(ind_part_data, "promis3a",
+                                     promis3a_related_words, multiple = TRUE)
+  promis3a_columnnames <- promis3a_details$name
+  ind_part_data <- data.frame(ind_part_data)
+  timepoint_details <- get_timepoint_details(ind_part_data)
+  if (sum(is.na(timepoint_details)) == 0) {
+    timepointscol <- timepoint_details$name
+    timepoints <- unique(ind_part_data[[timepointscol]])
+    nooftimepoints <- length(timepoints)
+  } else {
+    timepointscol <- NA
+    timepoints <- NA
+    nooftimepoints <- 1
+  }
+  for (j in 1:nooftimepoints) {
+    if (is.na(timepointscol) | timepointscol == "NA") {
+      rows_needed <- seq(1:nrow(ind_part_data))
+    } else {
+      rows_needed <- which(ind_part_data[[timepointscol]] == timepoints[j])
+    }
+    # get promis3a responses
+    promis3a_responses <- ind_part_data[rows_needed, promis3a_columnnames]
+    # remove those with non response codes, if missing data has been removed
+    # this will do no harm
+    if (is.na(promis3a_nrcode)) {
+      original_ind <- c()
+      ind <- c()
+      for (i in 1:ncol(promis3a_responses)) {
+        which_one <-  which(is.na(promis3a_responses[[i]]))
+        original_ind <- append(original_ind, rows_needed[which_one])
+        ind <- append(ind, which_one)
+      }
+    } else {
+      ind <- c()
+      original_ind <- c()
+      for (i in 1:ncol(promis3a_responses)) {
+        which_one <- which(promis3a_responses[[i]] == promis3a_nrcode)
+        original_ind <- append(original_ind, rows_needed[which_one])
+        ind <- append(ind, which_one)
+      }
+    }
+    ind <- sort(unique(ind))
+    original_ind <-  sort(unique(original_ind))
+    if (length(ind > 0))
+      promis3a_responses <- promis3a_responses[-ind, ]
+    # Check if the responses are 8 for an individual
+    if (length(promis3a_columnnames) != 3) {
+      stop("error- promis3a should have 3 columns")
+    } else {
+      # Check if the responses are numeric with range 1 to 5
+      results <- sapply(promis3a_columnnames, IPDFileCheck::test_data_numeric,
+                        promis3a_responses, promis3a_nrcode, 1, 5)
+    }
+    if (any(results < 0)) {
+      stop("promis3a responses do not seem right")
+    } else {
+
+      # Check if promis3a scoring table has columns defined in the config file
+      if (IPDFileCheck::test_columnnames(promis3a_scoring_data_columns,
+                                         promis3a_scores) == 0) {
+        # Replace NA with 0
+        promis3a_scores[is.na(promis3a_scores)] <- 0
+        # Find the sum of scores
+        sumpromis3a <- rowSums(promis3a_responses)
+        Tscorepromis3a <- rep(0, length(sumpromis3a))
+        for (i in seq_len(length(sumpromis3a))) {
+          ithrow <- which(promis3a_scores$Raw.score == sumpromis3a[i])
+          # Get the T score corresponding to raw sum
+          Tscorepromis3a[i] <- promis3a_scores$T.Score[ithrow]
+        }
+        # Add the T score to data , save and return
+        new_colname <- paste("promis3aTscore")
+        if (length(ind > 0))
+          rows_needed <- rows_needed[-ind]
+        ind_part_data[rows_needed, new_colname] <- Tscorepromis3a
+        if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- promis3a_nrcode
+
+        # Add the total raw score to data , save and return
+        new_colname <- paste("promis3a_rawscore")
+        ind_part_data[rows_needed, new_colname] <- sumpromis3a
+        if (length(original_ind > 0))
+          ind_part_data[original_ind, new_colname] <- promis3a_nrcode
+      } else {
+        stop("Error promis3a scoring column names are not equal to what specified
+             in configuration file")
+      }
     }
   }
   return(ind_part_data)
